==> dl.php?src=linea21_1_4.zip: linea21/languages/en/lang_workshop.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['workshop']['section'] = "workgroups";


/*	nommage des modules
 *  	*/
$lang['workshop']['name']='workgroup';
$lang['workshop']['confirm_add'] = "workgroup successfully added\n";
$lang['workshop']['confirm_mod'] = "workgroup successfully updated\n";
$lang['workshop']['confirm_sup'] ="workgroup successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['workshop']['add']= 'Add a new '.$lang['workshop']['name'];
$lang['workshop']['mod']= 'Edit '.$lang['workshop']['name'];
$lang['workshop']['sup']= 'Delete'.$lang['workshop']['name'];
$lang['workshop']['det']= ucfirst($lang['workshop']['name']) . ' details';
$lang['workshop']['list']= 'View workgroups';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['workshop']['add_title']='Add data about the new '.$lang['workshop']['name'];
$lang['workshop']['mod_title']='Edit data about '.$lang['workshop']['name'];
$lang['workshop']['recap_commment']='no comment';


/*	check integrité des données
 *  	*/
$lang['workshop']['no_title'] = 'Title is required';
$lang['workshop']['no_resume'] = 'Summary is required';
$lang['workshop']['no_theme'] = 'Theme is required';
$lang['workshop']['no_scale'] = 'Scale is required';
$lang['workshop']['no_level'] = 'Level is required';
$lang['workshop']['no_author'] = 'User login is required';
$lang['workshop']['yet_author'] = 'This user already belongs to this workgroup';
$lang['workshop']['author_not_valid'] = 'This user does not exist, please check the syntax';
$lang['workshop']['author_not_admin'] = 'This user does not have moderator rights';

/*	nommage élément rubrique
 *  	*/
$lang['workshop']['title']='title';
$lang['workshop']['resume']='summary';
$lang['workshop']['theme']='associated theme';
$lang['workshop']['level']='associated level';
$lang['workshop']['scale']='associated scale';
$lang['workshop']['statut']='status';
$lang['workshop']['comment']='comments';


$lang['workshop']['template']='template';
$lang['workshop']['photouri']='associated picture';
$lang['workshop']['visu1']='associated picture n°1';
$lang['workshop']['visu2']='associated picture n°2';
$lang['workshop']['organizer']='moderator (separated by ,)';
$lang['workshop']['organizer2']='moderators';
$lang['workshop']['published_on']='published on';
$lang['workshop']['not_published']='not published';

$lang['workshop']['generals']='global informations';
$lang['workshop']['mailing_list']='workgroup mailing-list';


/*	nommage quickbox
 *  	*/
$lang['workshop']['qb_titleadd']=' latest additions';
$lang['workshop']['qb_titlemod']=' latest modifications';
$lang['workshop']['qb_titlesup']=' latest deletions';
$lang['workshop']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/
$lang['workshop']['select_choice']="~~ Choose in this list ~~";
$lang['workshop']['nb_total']='workgroups in database.';
$lang['workshop']['statut_filter']='Display by status';
$lang['workshop']['all']='Display the whole list';
$lang['workshop']['noresult']='There is no workgroup with this criteria ';
$lang['workshop']['actions']='actions';

/*	nommage rubrique sup
 *  	*/
$lang['workshop']['sup_workshop_warning'] = "Do you really want to delete this " . $lang['workshop']['name'] . "?";



$lang['workshop']['cal_all']="Calendar";

$lang['workshop']['note_account']="To subscribe a workgroups, you must have an account and be logged-in.";
$lang['workshop']['subscribe_to']="Workgroups you want to subscribe to";
$lang['workshop']['get_involve']="Get involved";
$lang['workshop']['get_involve_long']="Get involved into workgroups";
$lang['workshop']['nogroup_selected']="Please, select at least one group.";
$lang['workshop']['confirm_request']="Your subscription request has been sent and will be effective soon.";
$lang['workshop']['workshop_back']="Get back to workgroup";
$lang['workshop']['noinscription']="You have not subscribed yet to this workgroup";
$lang['workshop']['creainscription']="Subscribe now to this workgroup!";
$lang['workshop']['creainscription2']="To subscribe";
$lang['workshop']['creainscription3']="Do you really want to subscribe to this workgroup ?";
$lang['workshop']['confirm_inscription']="successfully registered";
$lang['workshop']['com_p_back_com']="Click here to go to the forum";
$lang['workshop']['com_p_lock']="This topic is locked, you cannot post anymore";
$lang['workshop']['com_p_back_mes']="Click here to go back to the topic";
$lang['workshop']['participant']="Participate";
$lang['workshop']['barre_user']="Users";
$lang['workshop']['barre_report']="Reports";
$lang['workshop']['h1_public']="Our workgroups";
$lang['workshop']['h1_public_comment']="Workgroups are dedicated platforms to talk and work on specific topics : Be part of it!";

$lang['workshop']['confirm_add_u'] = "User successfully added in this workgroup\n";
$lang['workshop']['confirm_sup_u'] ="User successfully removed from this workgroup\n";

$lang['workshop']['user']='user(s) in this workgroup';
$lang['workshop']['add_new_user']="Add a new user";
$lang['workshop']['add_new_user_login']="user login";
$lang['workshop']['add_new_user_right']="user rights";
$lang['workshop']['no_user']="There is no user yet in this workgroup";
$lang['workshop']['del_user']="Remove user";
$lang['workshop']['mod_user']="Update user";
$lang['workshop']['del_user_warning']="Do you really want to remove this user from this workgroup? <br /> Caution, the removal will only take effect on this working group.";

$lang['workshop']['help_add_u1']='To add a workgroup, please insert the required informations in the form above';
$lang['workshop']['help_add_u2']='After submitting the form, check your data in the summary';
$lang['workshop']['help_add_u3']='After checking summary, click the \'review settings\' button to make new changes';
$lang['workshop']['help_add_u4']='Caution, users management is a deddicated module. In workgroup module, you can only add or remove user from workgroups';

$lang['workshop']['help_del_u1']='Click cancel to abort deletion.';
$lang['workshop']['help_del_u2']='Caution, this operation will remonly remove the user from this workgroup. To delete user go to user module';


$lang['workshop']['confirm_add_cal']="Task successfully added for this workgroup\n";
$lang['workshop']['confirm_sup_cal']="Task successfully deleted from this workgroup\n";
$lang['workshop']['confirm_mod_cal']="Task successfully updated for this workgroup\n";
$lang['workshop']['calendar']='Calendar';
$lang['workshop']['sup_cal_warning']="Do you really want to delete this task?";
$lang['workshop']['list_cal']="Calendar management";
$lang['workshop']['mod_cal']="Edit task";
$lang['workshop']['add_cal']="Add a new task";
$lang['workshop']['sup_cal']="Delete task";
$lang['workshop']['no_cal']="There is no task yet for this workgroup";
$lang['workshop']['no_task']="Title is required";
$lang['workshop']['no_task_details']="Description is required";
$lang['workshop']['date'] = "deadline";
//$lang['workshop']['day'] = "day";
//$lang['workshop']['month'] = "month";
//$lang['workshop']['year'] = "year";
$lang['workshop']['task']='title';
$lang['workshop']['task_details']='description';


$lang['workshop']['help_list_cal1']='Delete task by clicking on the delete icon linked in';
$lang['workshop']['help_list_cal2']='Edit task by clicking on the edit icon linked in';
$lang['workshop']['help_list_cal3']='To add a task, please insert the required informations in the form above';

$lang['workshop']['help_add_cal1']='To add a task, please insert the required informations in the form above';
$lang['workshop']['help_add_cal2']='After submitting the form, check your data in the summary';
$lang['workshop']['help_add_cal3']='After checking summary, click the \'review settings\' button to make new changes';

$lang['workshop']['help_mod_cal1']='To update fields, please insert the required informations in the form above';
$lang['workshop']['help_mod_cal2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_mod_cal3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_sup_cal1']='Click cancel to abort deletion.';



$lang['workshop']['report']='Workgroup report';
$lang['workshop']['no_report']="There is no report for this workgroup";
$lang['workshop']['title_report']="Title";
$lang['workshop']['resume_report']="Summary";
$lang['workshop']['date_report']="Published on";
$lang['workshop']['add_new_report']="Add a new report";
$lang['workshop']['del_report']="Delete this report";
$lang['workshop']['mod_report']="Update this report";




$lang['workshop']['com']='workgroup forum';
$lang['workshop']['com_public']='Forum';
$lang['workshop']['com_back']='Back to the topics list';
$lang['workshop']['com_name']='Topic';
$lang['workshop']['no_com']="There is no topic yet for this workgroup";
$lang['workshop']['no_com_rep']="Nobody posted a reply yet";
$lang['workshop']['com_list']="Forum manager";
$lang['workshop']['confirm_add_com']="Message successfully added\n";
$lang['workshop']['confirm_sup_com']="Message successfully deleted\n";
$lang['workshop']['confirm_lock_com']="Topic successfully locked\n";
$lang['workshop']['confirm_mod_com']="Message successfully updated\n";
$lang['workshop']['sup_ccom_warning']="Do you really want to delete this message?";
$lang['workshop']['list_com']="Forum manager";
$lang['workshop']['mod_com']="Edit this topic";
$lang['workshop']['mod_com_mes']="Edit this message";
$lang['workshop']['add_com']="Add a topic";
$lang['workshop']['add_com_mes']="Add a message";
$lang['workshop']['sup_com']="Delete this topic";
$lang['workshop']['sup_com_mes']="Delete this message";
$lang['workshop']['not_author']="You have to be the message's owner to edit this post!";

$lang['workshop']['det_com']="View the topic";
$lang['workshop']['nb_total_com']="topics in this workgroup";
$lang['workshop']['nb_total_com_mes']="messages in this topic";
$lang['workshop']['com_subject']="subject";
$lang['workshop']['com_body']="message";
$lang['workshop']['com_statut']="status";
$lang['workshop']['com_date_publi']="published on";
$lang['workshop']['com_nb_rep']='<abbr title="Reply numbers">rp nb</abbr>';
$lang['workshop']['com_date_last']="last message";
$lang['workshop']['com_author']="author";
$lang['workshop']['lock_com']="Lock this topic";
$lang['workshop']['unlock_com']="Unlock this topic";

$lang['workshop']['com_no_subject']="Subject is required.";
$lang['workshop']['com_no_body']="Body text is required.";

$lang['workshop']['sup_com_warning']="Do you really want to delete this topic ?";
$lang['workshop']['sup_com_warning2']="Caution, all messages will be deleted !";
$lang['workshop']['sup_com_mes_warning']="Do you really want to delete this message ?";

$lang['workshop']['lock_com_warning']="Do you really want to lock this topic ?";
$lang['workshop']['lock_com_warning2']="Caution, all messages will be locked  !";

$lang['workshop']['unlock_com_warning']="Do you really want to unlock this topic ?";
$lang['workshop']['unlock_com_warning2']="BCaution, all messages will be unlocked !";

$lang['workshop']['share_files'] = 'Check this box to share file(s) with other groups';
$lang['workshop']['shared_files'] = 'Shared files';
$lang['workshop']['files'] = 'Workgroup files';
$lang['workshop']['common_files'] = 'Common files';

$lang['workshop']['help_list_com1']='Delete topic by clicking on the delete icon linked in';
$lang['workshop']['help_list_com2']='Edit topic by clicking on the edit icon linked in';
$lang['workshop']['help_list_com3']='To add a topic, please insert the required informations in the form above';
$lang['workshop']['help_list_com4']='Click on topic title to display more informations';

$lang['workshop']['help_det_com1']='Delete message by clicking on the delete icon linked in';
$lang['workshop']['help_det_com2']='Edit message by clicking on the edit icon linked in';
$lang['workshop']['help_det_com3']='To add a new message, please insert the required informations in the form above';
$lang['workshop']['help_det_com4']='Lock topic by clicking on the lock icon linked in';


$lang['workshop']['help_add_com1']='To add a new topic or a new message, please insert the required informations in the form above';
$lang['workshop']['help_add_com2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_add_com3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_mod_com1']='To edit data, please update the required informations in the form above';
$lang['workshop']['help_mod_com2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_mod_com3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_sup_com1']='Click cancel to abort deletion.';
$lang['workshop']['help_sup_com2']='Caution, all messages will be deleted if the message is a root topic !';

$lang['workshop']['help_lock_com1']='Click cancel to abort unlocking.';
$lang['workshop']['help_lock_com2']='A locked topic is readable but no message can be added to this topic';
$lang['workshop']['help_lock_com3']='Unlock topic by clicking on the unlock icon linked in';



$lang['workshop']['help_add1']='To add a new workgroup, please insert the required informations in the form above';
$lang['workshop']['help_add2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_add3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_list1']='Click on workgroup titles to display more informations';
$lang['workshop']['help_list2']='Delete workgroup by clicking on the delete icon linked in';
$lang['workshop']['help_list3']='Edit workgroup by clicking on the edit icon linked in';
$lang['workshop']['help_list4']='Filter by status to display workgroup for one status';
$lang['workshop']['help_list5']='To add a new workgroup, please insert the required informations in the form above';


$lang['workshop']['help_mod1']='To edit data, please update the required informations in the form above';
$lang['workshop']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_mod3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_det1']="Edit workgroup by clicking on the edit icon linked in";
$lang['workshop']['help_det2']="Delete workgroup by clicking on the delete icon linked in";
$lang['workshop']['help_det4']="Click on workgroup report or users to display more informations";
$lang['workshop']['help_det5']="To add a user, click on the add icon";
$lang['workshop']['help_det6']="Edit workgroup user and rights by clicking on edit icon linked in";
$lang['workshop']['help_det7']="Edit workgroup report by clicking on the edit icon linked in";
$lang['workshop']['help_det8']="Delete workgroup report by clicking on the delete icon linked in.";


$lang['workshop']['help_sup1']='Click cancel to abort deletion.';

/*	mail
 **/
$lang['workshop']['mail_file_body1'] = 'New files were added to <strong>%s</strong> workgroup';
$lang['workshop']['mail_file_body2'] = '%s added the following file(s) :';
$lang['workshop']['mail_file_subject'] = '%s -  new file(s) - %s';

$lang['workshop']['mail_topic_body1'] = '<em>%s</em> has created the topic <strong>%s</strong> into <em>%s</em> workgroup';
$lang['workshop']['mail_post_body1'] = '<em>%s</em> wrote a new message in <strong>%s</strong> (workgroup : <em>%s</em>).';
$lang['workshop']['mail_msg_content'] = 'Message content';
$lang['workshop']['mail_topic_subject'] = '%s -  new topic- %s';
$lang['workshop']['mail_post_subject'] = '%s -  new post - %s';

$lang['workshop']['mail_request_subject'] = 'Workgroup(s) subscription request';
$lang['workshop']['workgroup_request'] = "<em>%s</em> wants to subscribe the following group(s) :";


$lang['workshop']['mail_body_url'] = 'Please, follow the url: ';
$lang['workshop']['mail_body_auth'] = 'Important : You must be logged-in to access the page.';

?>

==> dl.php?src=linea21_1_6.zip: linea21/languages/en/lang_workshop.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['workshop']['section'] = "workgroups";


/*	nommage des modules
 *  	*/
$lang['workshop']['name']='workgroup';
$lang['workshop']['confirm_add'] = "workgroup successfully added\n";
$lang['workshop']['confirm_mod'] = "workgroup successfully updated\n";
$lang['workshop']['confirm_sup'] ="workgroup successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['workshop']['add']= 'Add a new '.$lang['workshop']['name'];
$lang['workshop']['mod']= 'Edit '.$lang['workshop']['name'];
$lang['workshop']['sup']= 'Delete'.$lang['workshop']['name'];
$lang['workshop']['det']= ucfirst($lang['workshop']['name']) . ' details';
$lang['workshop']['list']= 'View workgroups';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['workshop']['add_title']='Add data about the new '.$lang['workshop']['name'];
$lang['workshop']['mod_title']='Edit data about '.$lang['workshop']['name'];
$lang['workshop']['recap_commment']='no comment';


/*	check integrité des données
 *  	*/
$lang['workshop']['no_title'] = 'Title is required';
$lang['workshop']['no_resume'] = 'Summary is required';
$lang['workshop']['no_theme'] = 'Theme is required';
$lang['workshop']['no_scale'] = 'Scale is required';
$lang['workshop']['no_level'] = 'Level is required';
$lang['workshop']['no_author'] = 'User login is required';
$lang['workshop']['yet_author'] = 'This user already belongs to this workgroup';
$lang['workshop']['author_not_valid'] = 'This user does not exist, please check the syntax';
$lang['workshop']['author_not_admin'] = 'This user does not have leader rights';
$lang['workshop']['author_not_allowed'] = 'The user does not exist or do not belong to the group';

/*	nommage élément rubrique
 *  	*/
$lang['workshop']['title']='title';
$lang['workshop']['resume']='summary';
$lang['workshop']['theme']='associated theme';
$lang['workshop']['level']='associated level';
$lang['workshop']['scale']='associated scale';
$lang['workshop']['statut']='status';
$lang['workshop']['comment']='comments';


$lang['workshop']['template']='template';
$lang['workshop']['photouri']='associated picture';
$lang['workshop']['visu1']='associated picture n°1';
$lang['workshop']['visu2']='associated picture n°2';
$lang['workshop']['organizer']='leaders (separated by ,)';
$lang['workshop']['organizer2']='leaders';
$lang['workshop']['published_on']='published on';
$lang['workshop']['not_published']='not published';
$lang['workshop']['access_to']='→ Access to the group';

$lang['workshop']['generals']='global informations';
$lang['workshop']['mailing_list']='workgroup mailing-list';


/*	nommage quickbox
 *  	*/
$lang['workshop']['qb_titleadd']=' latest additions';
$lang['workshop']['qb_titlemod']=' latest modifications';
$lang['workshop']['qb_titlesup']=' latest deletions';
$lang['workshop']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/
$lang['workshop']['select_choice']="-- Choose in this list --";
$lang['workshop']['nb_total']='workgroups in database.';
$lang['workshop']['statut_filter']='Display by status';
$lang['workshop']['all']='Display the whole list';
$lang['workshop']['noresult']='There is no workgroup with this criteria ';
$lang['workshop']['actions']='actions';

/*	nommage rubrique sup
 *  	*/
$lang['workshop']['sup_workshop_warning'] = "Do you really want to delete this " . $lang['workshop']['name'] . "?";



$lang['workshop']['cal_all']="Calendar";

$lang['workshop']['note_account']="To subscribe a workgroups, you must have an account and be logged-in.";
$lang['workshop']['subscribe_to']="Workgroups you want to subscribe to";
$lang['workshop']['get_involve']="Get involved";
$lang['workshop']['get_involve_long']="Get involved into workgroups";
$lang['workshop']['allgroups_subscribed']="You are already involved in all workgroups!";
$lang['workshop']['subscription_confirmed']="Subscription confirmed";
$lang['workshop']['nogroup_selected']="Please, select at least one group.";
$lang['workshop']['confirm_request']="Your subscription request has been sent and will be effective soon.";
$lang['workshop']['workshop_back']="Get back to workgroup";
$lang['workshop']['noinscription']="You have not subscribed yet to this workgroup";
$lang['workshop']['creainscription']="Subscribe now to this workgroup!";
$lang['workshop']['creainscription2']="To subscribe";
$lang['workshop']['creainscription3']="Do you really want to subscribe to this workgroup ?";
$lang['workshop']['confirm_inscription']="successfully registered";
$lang['workshop']['com_p_back_com']="Click here to go to the forum";
$lang['workshop']['com_p_lock']="This topic is locked, you cannot post anymore";
$lang['workshop']['com_p_back_mes']="Click here to go back to the topic";
$lang['workshop']['participant']="Subscribers";
$lang['workshop']['barre_user']="Users";
$lang['workshop']['barre_report']="Reports";
$lang['workshop']['h1_public']="Our workgroups";
$lang['workshop']['h1_public_comment']="Workgroups are dedicated platforms to talk and work on specific topics : Be part of it!";

$lang['workshop']['confirm_add_u'] = "User successfully added in this workgroup\n";
$lang['workshop']['confirm_sup_u'] ="User successfully removed from this workgroup\n";

$lang['workshop']['user']='user(s) in this workgroup';
$lang['workshop']['add_new_user']="Add a new user";
$lang['workshop']['add_new_user_login']="user login";
$lang['workshop']['add_new_user_right']="user rights";
$lang['workshop']['no_user']="There is no user yet in this workgroup";
$lang['workshop']['del_user']="Remove user";
$lang['workshop']['mod_user']="Update user";
$lang['workshop']['del_user_warning']="Do you really want to remove this user from this workgroup? <br /> Caution, the removal will only take effect on this working group.";

$lang['workshop']['help_add_u1']='To add a workgroup, please insert the required informations in the form above';
$lang['workshop']['help_add_u2']='After submitting the form, check your data in the summary';
$lang['workshop']['help_add_u3']='After checking summary, click the \'review settings\' button to make new changes';
$lang['workshop']['help_add_u4']='Caution, users management is a deddicated module. In workgroup module, you can only add or remove user from workgroups';

$lang['workshop']['help_del_u1']='Click cancel to abort deletion.';
$lang['workshop']['help_del_u2']='Caution, this operation will remonly remove the user from this workgroup. To delete user go to user module';


$lang['workshop']['confirm_add_cal']="Task successfully added for this workgroup\n";
$lang['workshop']['confirm_sup_cal']="Task successfully deleted from this workgroup\n";
$lang['workshop']['confirm_mod_cal']="Task successfully updated for this workgroup\n";
$lang['workshop']['calendar']='Calendar';
$lang['workshop']['sup_cal_warning']="Do you really want to delete this task?";
$lang['workshop']['list_cal']="Calendar management";
$lang['workshop']['list_doc']="Documents management";
$lang['workshop']['mod_cal']="Edit task";
$lang['workshop']['add_cal']="Add a new task";
$lang['workshop']['sup_cal']="Delete task";
$lang['workshop']['no_cal']="There is no task yet for this workgroup";
$lang['workshop']['no_task']="Title is required";
$lang['workshop']['no_task_details']="Description is required";
$lang['workshop']['date'] = "deadline";
//$lang['workshop']['day'] = "day";
//$lang['workshop']['month'] = "month";
//$lang['workshop']['year'] = "year";
$lang['workshop']['task']='title';
$lang['workshop']['task_details']='description';
$lang['workshop']['task_common']='Task common to all workgroups';



$lang['workshop']['help_list_cal1']='Delete task by clicking on the delete icon linked in';
$lang['workshop']['help_list_cal2']='Edit task by clicking on the edit icon linked in';
$lang['workshop']['help_list_cal3']='To add a task, please insert the required informations in the form above';

$lang['workshop']['help_add_cal1']='To add a task, please insert the required informations in the form above';
$lang['workshop']['help_add_cal2']='After submitting the form, check your data in the summary';
$lang['workshop']['help_add_cal3']='After checking summary, click the \'review settings\' button to make new changes';

$lang['workshop']['help_mod_cal1']='To update fields, please insert the required informations in the form above';
$lang['workshop']['help_mod_cal2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_mod_cal3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_sup_cal1']='Click cancel to abort deletion.';



$lang['workshop']['report']='Workgroup reports';
$lang['workshop']['archived_report']='Archived workgroup reports';
$lang['workshop']['no_report']="There is no report for this workgroup";
$lang['workshop']['title_report']="Title";
$lang['workshop']['resume_report']="Summary";
$lang['workshop']['date_report']="Published on";
$lang['workshop']['add_new_report']="Add a new report";
$lang['workshop']['del_report']="Delete this report";
$lang['workshop']['mod_report']="Update this report";




$lang['workshop']['com']='workgroup forum';
$lang['workshop']['com_public']='Forum';
$lang['workshop']['com_back']='Back to the topics list';
$lang['workshop']['com_name']='Topic';
$lang['workshop']['no_com']="There is no topic yet for this workgroup";
$lang['workshop']['no_com_rep']="Nobody posted a reply yet";
$lang['workshop']['com_list']="Forum manager";
$lang['workshop']['confirm_add_com']="Message successfully added\n";
$lang['workshop']['confirm_sup_com']="Message successfully deleted\n";
$lang['workshop']['confirm_lock_com']="Topic successfully locked\n";
$lang['workshop']['confirm_mod_com']="Message successfully updated\n";
$lang['workshop']['sup_ccom_warning']="Do you really want to delete this message?";
$lang['workshop']['list_com']="Forum manager";
$lang['workshop']['mod_com']="Edit this topic";
$lang['workshop']['mod_com_mes']="Edit this message";
$lang['workshop']['add_com']="Add a topic";
$lang['workshop']['add_com_mes']="Add a message";
$lang['workshop']['sup_com']="Delete this topic";
$lang['workshop']['sup_com_mes']="Delete this message";
$lang['workshop']['not_author']="You have to be the message's owner to edit this post!";

$lang['workshop']['det_com']="View the topic";
$lang['workshop']['nb_total_com']="topics in this workgroup";
$lang['workshop']['nb_total_com_mes']="messages in this topic";
$lang['workshop']['com_subject']="subject";
$lang['workshop']['com_body']="message";
$lang['workshop']['com_owner']="owner's message";
$lang['workshop']['com_change_owner']="change owner's message ?";
$lang['workshop']['com_notify']="notify workgroup subscribers";
$lang['workshop']['com_statut']="status";
$lang['workshop']['com_date_publi']="published on";
$lang['workshop']['com_nb_rep']='<abbr title="Reply numbers">rp nb</abbr>';
$lang['workshop']['com_date_last']="last message";
$lang['workshop']['com_author']="author";
$lang['workshop']['lock_com']="Lock this topic";
$lang['workshop']['unlock_com']="Unlock this topic";

$lang['workshop']['com_no_subject']="Subject is required.";
$lang['workshop']['com_no_body']="Body text is required.";

$lang['workshop']['sup_com_warning']="Do you really want to delete this topic ?";
$lang['workshop']['sup_com_warning2']="Caution, all messages will be deleted !";
$lang['workshop']['sup_com_mes_warning']="Do you really want to delete this message ?";

$lang['workshop']['lock_com_warning']="Do you really want to lock this topic ?";
$lang['workshop']['lock_com_warning2']="Caution, all messages will be locked  !";

$lang['workshop']['unlock_com_warning']="Do you really want to unlock this topic ?";
$lang['workshop']['unlock_com_warning2']="BCaution, all messages will be unlocked !";

$lang['workshop']['share_files'] = 'Check this box to share file(s) with other groups';
$lang['workshop']['shared_files'] = 'Shared files';
$lang['workshop']['files'] = 'Workgroup files';
$lang['workshop']['common_files'] = 'Common files';

$lang['workshop']['help_list_com1']='Delete topic by clicking on the delete icon linked in';
$lang['workshop']['help_list_com2']='Edit topic by clicking on the edit icon linked in';
$lang['workshop']['help_list_com3']='To add a topic, please insert the required informations in the form above';
$lang['workshop']['help_list_com4']='Click on topic title to display more informations';

$lang['workshop']['help_det_com1']='Delete message by clicking on the delete icon linked in';
$lang['workshop']['help_det_com2']='Edit message by clicking on the edit icon linked in';
$lang['workshop']['help_det_com3']='To add a new message, please insert the required informations in the form above';
$lang['workshop']['help_det_com4']='Lock topic by clicking on the lock icon linked in';


$lang['workshop']['help_add_com1']='To add a new topic or a new message, please insert the required informations in the form above';
$lang['workshop']['help_add_com2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_add_com3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_mod_com1']='To edit data, please update the required informations in the form above';
$lang['workshop']['help_mod_com2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_mod_com3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_sup_com1']='Click cancel to abort deletion.';
$lang['workshop']['help_sup_com2']='Caution, all messages will be deleted if the message is a root topic !';

$lang['workshop']['help_lock_com1']='Click cancel to abort unlocking.';
$lang['workshop']['help_lock_com2']='A locked topic is readable but no message can be added to this topic';
$lang['workshop']['help_lock_com3']='Unlock topic by clicking on the unlock icon linked in';



$lang['workshop']['help_add1']='To add a new workgroup, please insert the required informations in the form above';
$lang['workshop']['help_add2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_add3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_list1']='Click on workgroup titles to display more informations';
$lang['workshop']['help_list2']='Delete workgroup by clicking on the delete icon linked in';
$lang['workshop']['help_list3']='Edit workgroup by clicking on the edit icon linked in';
$lang['workshop']['help_list4']='Filter by status to display workgroup for one status';
$lang['workshop']['help_list5']='To add a new workgroup, please insert the required informations in the form above';


$lang['workshop']['help_mod1']='To edit data, please update the required informations in the form above';
$lang['workshop']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['workshop']['help_mod3']='Once the summary displayed, click the \'review settings\' button to make new changes';

$lang['workshop']['help_det1']="Edit workgroup by clicking on the edit icon linked in";
$lang['workshop']['help_det2']="Delete workgroup by clicking on the delete icon linked in";
$lang['workshop']['help_det4']="Click on workgroup report or users to display more informations";
$lang['workshop']['help_det5']="To add a user, click on the add icon";
$lang['workshop']['help_det6']="Edit workgroup user and rights by clicking on edit icon linked in";
$lang['workshop']['help_det7']="Edit workgroup report by clicking on the edit icon linked in";
$lang['workshop']['help_det8']="Delete workgroup report by clicking on the delete icon linked in.";


$lang['workshop']['help_sup1']='Click cancel to abort deletion.';

/*	mail
 **/
$lang['workshop']['mail_file_body1'] = 'New files were added to <strong>%s</strong> workgroup';
$lang['workshop']['mail_file_body2'] = '%s added the following file(s) :';
$lang['workshop']['mail_file_subject'] = '%s -  new file(s) - %s';

$lang['workshop']['mail_calendar_body1'] = '<em>%s</em> added a new event called "<em>%s</em>" into <strong>%s</strong>\'s workgroup (planned on %s)'; // @todo translation
$lang['workshop']['mail_calendar_body2'] = 'Event details :'; // @todo translation
$lang['workshop']['mail_calendar_subject'] = '%s -  new event - %s'; // @todo translation

$lang['workshop']['mail_topic_body1'] = '<em>%s</em> has created the topic <strong>%s</strong> into <em>%s</em> workgroup';
$lang['workshop']['mail_post_body1'] = '<em>%s</em> wrote a new message in <strong>%s</strong> (workgroup : <em>%s</em>).';
$lang['workshop']['mail_msg_content'] = 'Message content';
$lang['workshop']['mail_topic_subject'] = '%s -  new topic- %s';
$lang['workshop']['mail_post_subject'] = '%s -  new post - %s';

$lang['workshop']['mail_request_subject'] = 'Workgroup(s) subscription request';
$lang['workshop']['workgroup_request'] = "<em>%s</em> wants to subscribe the following group(s) :";
$lang['workshop']['workshop_join']="wants to subscribe %s group";


$lang['workshop']['mail_body_url'] = 'Please, follow the url: ';
$lang['workshop']['mail_body_auth'] = 'Important : You must be logged-in to access the page.';

?>
